[network-manager-applet] connection-editor: rename "wired" and "wireless" in files/classes/functions



commit 44fc72f59c16ee6d74061d73b84a7459eb44e909
Author: Dan Winship <danw gnome org>
Date:   Thu Aug 9 09:22:51 2012 -0400

    connection-editor: rename "wired" and "wireless" in files/classes/functions
    
    Update internal names to match the UI.

 src/connection-editor/Makefile.am                  |   22 ++--
 .../{ce-page-wired.ui => ce-page-ethernet.ui}      |   30 ++--
 ...reless-security.ui => ce-page-wifi-security.ui} |   10 +-
 .../{ce-page-wireless.ui => ce-page-wifi.ui}       |   66 +++++-----
 src/connection-editor/main.c                       |    1 -
 src/connection-editor/new-connection.c             |    6 +-
 src/connection-editor/nm-connection-editor.c       |   18 ++--
 src/connection-editor/nm-connection-list.c         |    7 -
 ...page-wired-security.c => page-8021x-security.c} |   44 +++---
 ...page-wired-security.h => page-8021x-security.h} |   26 ++--
 .../{page-wired.c => page-ethernet.c}              |  110 ++++++++--------
 .../{page-wireless.h => page-ethernet.h}           |   40 +++---
 src/connection-editor/page-ip4.c                   |    2 +-
 src/connection-editor/page-ip6.c                   |    2 +-
 ...ge-wireless-security.c => page-wifi-security.c} |   64 +++++-----
 src/connection-editor/page-wifi-security.h         |   65 +++++++++
 .../{page-wireless.c => page-wifi.c}               |  140 ++++++++++----------
 .../{page-wireless.h => page-wifi.h}               |   36 +++---
 src/connection-editor/page-wired.h                 |   63 ---------
 src/connection-editor/page-wireless-security.h     |   65 ---------
 20 files changed, 371 insertions(+), 446 deletions(-)
---
diff --git a/src/connection-editor/Makefile.am b/src/connection-editor/Makefile.am
index f22c9f9..564127c 100644
--- a/src/connection-editor/Makefile.am
+++ b/src/connection-editor/Makefile.am
@@ -26,14 +26,14 @@ nm_connection_editor_SOURCES = \
 	main.c \
 	ce-page.h \
 	ce-page.c \
-	page-wired.h \
-	page-wired.c \
-	page-wired-security.h \
-	page-wired-security.c \
-	page-wireless.h \
-	page-wireless.c \
-	page-wireless-security.h \
-	page-wireless-security.c \
+	page-ethernet.h \
+	page-ethernet.c \
+	page-8021x-security.h \
+	page-8021x-security.c \
+	page-wifi.h \
+	page-wifi.c \
+	page-wifi-security.h \
+	page-wifi-security.c \
 	page-wimax.h \
 	page-wimax.c \
 	page-infiniband.h \
@@ -79,9 +79,9 @@ uidir = $(datadir)/nm-applet
 ui_DATA = \
 	nm-connection-editor.ui \
 	ce-new-connection.ui \
-	ce-page-wired.ui \
-	ce-page-wireless.ui \
-	ce-page-wireless-security.ui \
+	ce-page-ethernet.ui \
+	ce-page-wifi.ui \
+	ce-page-wifi-security.ui \
 	ce-page-wimax.ui \
 	ce-page-infiniband.ui \
 	ce-page-ip4.ui \
diff --git a/src/connection-editor/ce-page-wired.ui b/src/connection-editor/ce-page-ethernet.ui
similarity index 91%
rename from src/connection-editor/ce-page-wired.ui
rename to src/connection-editor/ce-page-ethernet.ui
index d230c12..48039cb 100644
--- a/src/connection-editor/ce-page-wired.ui
+++ b/src/connection-editor/ce-page-ethernet.ui
@@ -54,7 +54,7 @@
       </row>
     </data>
   </object>
-      <object class="GtkTable" id="WiredPage">
+      <object class="GtkTable" id="EthernetPage">
         <property name="visible">True</property>
         <property name="border_width">12</property>
         <property name="n_rows">6</property>
@@ -62,12 +62,12 @@
         <property name="column_spacing">12</property>
         <property name="row_spacing">6</property>
         <child>
-          <object class="GtkLabel" id="wired_port_label">
+          <object class="GtkLabel" id="ethernet_port_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">_Port:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wired_port</property>
+            <property name="mnemonic_widget">ethernet_port</property>
           </object>
           <packing>
             <property name="x_options">GTK_FILL</property>
@@ -75,7 +75,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkComboBox" id="wired_port">
+          <object class="GtkComboBox" id="ethernet_port">
             <property name="visible">True</property>
             <property name="model">model1</property>
             <child>
@@ -92,12 +92,12 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="wired_speed_label">
+          <object class="GtkLabel" id="ethernet_speed_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">_Speed:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wired_speed</property>
+            <property name="mnemonic_widget">ethernet_speed</property>
           </object>
           <packing>
             <property name="top_attach">1</property>
@@ -107,7 +107,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkComboBox" id="wired_speed">
+          <object class="GtkComboBox" id="ethernet_speed">
             <property name="visible">True</property>
             <property name="model">model2</property>
             <child>
@@ -126,7 +126,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkCheckButton" id="wired_duplex">
+          <object class="GtkCheckButton" id="ethernet_duplex">
             <property name="label" translatable="yes">Full duple_x</property>
             <property name="visible">True</property>
             <property name="can_focus">True</property>
@@ -143,7 +143,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkCheckButton" id="wired_autonegotiate">
+          <object class="GtkCheckButton" id="ethernet_autonegotiate">
             <property name="label" translatable="yes">Aut_onegotiate</property>
             <property name="visible">True</property>
             <property name="can_focus">True</property>
@@ -160,7 +160,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="wired_device_mac_label">
+          <object class="GtkLabel" id="ethernet_device_mac_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">_Device MAC address:</property>
@@ -174,7 +174,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkAlignment" id="wired_device_mac_alignment">
+          <object class="GtkAlignment" id="ethernet_device_mac_alignment">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <child>
@@ -195,7 +195,7 @@
             <property name="xalign">0</property>
             <property name="label" translatable="yes">C_loned MAC address:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wired_cloned_mac</property>
+            <property name="mnemonic_widget">ethernet_cloned_mac</property>
           </object>
           <packing>
             <property name="top_attach">5</property>
@@ -205,7 +205,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkEntry" id="wired_cloned_mac">
+          <object class="GtkEntry" id="ethernet_cloned_mac">
             <property name="visible">True</property>
             <property name="can_focus">True</property>
             <property name="tooltip_text" translatable="yes">The MAC address entered here will be used as hardware address for the network device this connection is activated on.  This feature is known as MAC cloning or spoofing.  Example: 00:11:22:33:44:55</property>
@@ -224,7 +224,7 @@
             <property name="xalign">0</property>
             <property name="label" translatable="yes">_MTU:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wired_mtu</property>
+            <property name="mnemonic_widget">ethernet_mtu</property>
           </object>
           <packing>
             <property name="top_attach">6</property>
@@ -238,7 +238,7 @@
             <property name="visible">True</property>
             <property name="spacing">6</property>
             <child>
-              <object class="GtkSpinButton" id="wired_mtu">
+              <object class="GtkSpinButton" id="ethernet_mtu">
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="adjustment">adjustment1</property>
diff --git a/src/connection-editor/ce-page-wireless-security.ui b/src/connection-editor/ce-page-wifi-security.ui
similarity index 86%
rename from src/connection-editor/ce-page-wireless-security.ui
rename to src/connection-editor/ce-page-wifi-security.ui
index 63b5033..9d14013 100644
--- a/src/connection-editor/ce-page-wireless-security.ui
+++ b/src/connection-editor/ce-page-wifi-security.ui
@@ -13,7 +13,7 @@
       </row>
     </data>
   </object>
-      <object class="GtkTable" id="WirelessSecurityPage">
+      <object class="GtkTable" id="WifiSecurityPage">
         <property name="visible">True</property>
         <property name="border_width">12</property>
         <property name="n_rows">2</property>
@@ -21,12 +21,12 @@
         <property name="column_spacing">12</property>
         <property name="row_spacing">6</property>
         <child>
-          <object class="GtkLabel" id="wireless_security_combo_label">
+          <object class="GtkLabel" id="wifi_security_combo_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">S_ecurity:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wireless_security_combo</property>
+            <property name="mnemonic_widget">wifi_security_combo</property>
           </object>
           <packing>
             <property name="x_options">GTK_FILL</property>
@@ -34,7 +34,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkComboBox" id="wireless_security_combo">
+          <object class="GtkComboBox" id="wifi_security_combo">
             <property name="visible">True</property>
             <property name="model">model1</property>
             <child>
@@ -51,7 +51,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkVBox" id="wireless_security_vbox">
+          <object class="GtkVBox" id="wifi_security_vbox">
             <property name="visible">True</property>
             <child>
               <placeholder/>
diff --git a/src/connection-editor/ce-page-wireless.ui b/src/connection-editor/ce-page-wifi.ui
similarity index 88%
rename from src/connection-editor/ce-page-wireless.ui
rename to src/connection-editor/ce-page-wifi.ui
index 065eaca..72df449 100644
--- a/src/connection-editor/ce-page-wireless.ui
+++ b/src/connection-editor/ce-page-wifi.ui
@@ -57,7 +57,7 @@
       </row>
     </data>
   </object>
-      <object class="GtkTable" id="WirelessPage">
+      <object class="GtkTable" id="WifiPage">
         <property name="visible">True</property>
         <property name="border_width">12</property>
         <property name="n_rows">9</property>
@@ -65,11 +65,11 @@
         <property name="column_spacing">12</property>
         <property name="row_spacing">6</property>
         <child>
-          <object class="GtkHBox" id="wireless_mtu_hbox">
+          <object class="GtkHBox" id="wifi_mtu_hbox">
             <property name="visible">True</property>
             <property name="spacing">6</property>
             <child>
-              <object class="GtkSpinButton" id="wireless_mtu">
+              <object class="GtkSpinButton" id="wifi_mtu">
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="adjustment">adjustment1</property>
@@ -102,12 +102,12 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="wireless_mtu_label">
+          <object class="GtkLabel" id="wifi_mtu_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">_MTU:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wireless_mtu</property>
+            <property name="mnemonic_widget">wifi_mtu</property>
           </object>
           <packing>
             <property name="top_attach">9</property>
@@ -117,7 +117,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkAlignment" id="wireless_device_mac_alignment">
+          <object class="GtkAlignment" id="wifi_device_mac_alignment">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <child>
@@ -133,7 +133,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="wireless_device_mac_label">
+          <object class="GtkLabel" id="wifi_device_mac_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">_Device MAC address:</property>
@@ -147,7 +147,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkEntry" id="wireless_cloned_mac">
+          <object class="GtkEntry" id="wifi_cloned_mac">
             <property name="visible">True</property>
             <property name="can_focus">True</property>
             <property name="tooltip_text" translatable="yes">The MAC address entered here will be used as hardware address for the network device this connection is activated on.  This feature is known as MAC cloning or spoofing.  Example: 00:11:22:33:44:55</property>
@@ -161,12 +161,12 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="wireless_cloned_mac_label">
+          <object class="GtkLabel" id="wifi_cloned_mac_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">C_loned MAC address:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wireless_cloned_mac</property>
+            <property name="mnemonic_widget">wifi_cloned_mac</property>
           </object>
           <packing>
             <property name="top_attach">8</property>
@@ -176,11 +176,11 @@
           </packing>
         </child>
         <child>
-          <object class="GtkHBox" id="wireless_tx_power_hbox">
+          <object class="GtkHBox" id="wifi_tx_power_hbox">
             <property name="visible">True</property>
             <property name="spacing">6</property>
             <child>
-              <object class="GtkSpinButton" id="wireless_tx_power">
+              <object class="GtkSpinButton" id="wifi_tx_power">
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="adjustment">adjustment2</property>
@@ -213,12 +213,12 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="wireless_tx_power_label">
+          <object class="GtkLabel" id="wifi_tx_power_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">Transmission po_wer:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wireless_tx_power</property>
+            <property name="mnemonic_widget">wifi_tx_power</property>
           </object>
           <packing>
             <property name="top_attach">6</property>
@@ -228,11 +228,11 @@
           </packing>
         </child>
         <child>
-          <object class="GtkHBox" id="wireless_rate_hbox">
+          <object class="GtkHBox" id="wifi_rate_hbox">
             <property name="visible">True</property>
             <property name="spacing">6</property>
             <child>
-              <object class="GtkSpinButton" id="wireless_rate">
+              <object class="GtkSpinButton" id="wifi_rate">
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="adjustment">adjustment3</property>
@@ -265,12 +265,12 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="wireless_rate_label">
+          <object class="GtkLabel" id="wifi_rate_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">_Rate:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wireless_rate</property>
+            <property name="mnemonic_widget">wifi_rate</property>
           </object>
           <packing>
             <property name="top_attach">5</property>
@@ -280,7 +280,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkEntry" id="wireless_bssid">
+          <object class="GtkEntry" id="wifi_bssid">
             <property name="visible">True</property>
             <property name="can_focus">True</property>
             <property name="tooltip_text" translatable="yes">This option locks this connection to the Wi-Fi access point (AP) specified by the BSSID entered here.  Example: 00:11:22:33:44:55</property>
@@ -294,7 +294,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkEntry" id="wireless_ssid">
+          <object class="GtkEntry" id="wifi_ssid">
             <property name="visible">True</property>
             <property name="can_focus">True</property>
           </object>
@@ -305,12 +305,12 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="wireless_bssid_label">
+          <object class="GtkLabel" id="wifi_bssid_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">_BSSID:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wireless_bssid</property>
+            <property name="mnemonic_widget">wifi_bssid</property>
           </object>
           <packing>
             <property name="top_attach">4</property>
@@ -320,7 +320,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkSpinButton" id="wireless_channel">
+          <object class="GtkSpinButton" id="wifi_channel">
             <property name="visible">True</property>
             <property name="can_focus">True</property>
             <property name="adjustment">adjustment4</property>
@@ -335,12 +335,12 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="wireless_channel_label">
+          <object class="GtkLabel" id="wifi_channel_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">C_hannel:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wireless_channel</property>
+            <property name="mnemonic_widget">wifi_channel</property>
           </object>
           <packing>
             <property name="top_attach">3</property>
@@ -350,7 +350,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkComboBox" id="wireless_band">
+          <object class="GtkComboBox" id="wifi_band">
             <property name="visible">True</property>
             <property name="model">model1</property>
             <child>
@@ -370,12 +370,12 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="wireless_band_label">
+          <object class="GtkLabel" id="wifi_band_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">Ban_d:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wireless_band</property>
+            <property name="mnemonic_widget">wifi_band</property>
           </object>
           <packing>
             <property name="top_attach">2</property>
@@ -385,7 +385,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkComboBox" id="wireless_mode">
+          <object class="GtkComboBox" id="wifi_mode">
             <property name="visible">True</property>
             <property name="model">model2</property>
             <child>
@@ -405,12 +405,12 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="wireless_mode_label">
+          <object class="GtkLabel" id="wifi_mode_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">M_ode:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wireless_mode</property>
+            <property name="mnemonic_widget">wifi_mode</property>
           </object>
           <packing>
             <property name="top_attach">1</property>
@@ -420,12 +420,12 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="wireless_ssid_label">
+          <object class="GtkLabel" id="wifi_ssid_label">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="label" translatable="yes">SS_ID:</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">wireless_ssid</property>
+            <property name="mnemonic_widget">wifi_ssid</property>
           </object>
           <packing>
             <property name="x_options">GTK_FILL</property>
diff --git a/src/connection-editor/main.c b/src/connection-editor/main.c
index fc32a41..0bd7ecb 100644
--- a/src/connection-editor/main.c
+++ b/src/connection-editor/main.c
@@ -41,7 +41,6 @@
 #include <nm-setting-cdma.h>
 #include "nm-connection-list.h"
 #include "nm-connection-editor.h"
-#include "page-wired.h"
 
 static GMainLoop *loop = NULL;
 
diff --git a/src/connection-editor/new-connection.c b/src/connection-editor/new-connection.c
index cda581e..5e2c9f7 100644
--- a/src/connection-editor/new-connection.c
+++ b/src/connection-editor/new-connection.c
@@ -24,8 +24,8 @@
 
 #include "new-connection.h"
 #include "nm-connection-list.h"
-#include "page-wired.h"
-#include "page-wireless.h"
+#include "page-ethernet.h"
+#include "page-wifi.h"
 #include "page-mobile.h"
 #include "page-wimax.h"
 #include "page-dsl.h"
@@ -87,7 +87,7 @@ get_connection_type_list (void)
 
 	data.name = _("Ethernet");
 	ICON_LOAD (data.icon, "nm-device-wired");
-	data.new_connection_func = wired_connection_new;
+	data.new_connection_func = ethernet_connection_new;
 	data.setting_type = NM_TYPE_SETTING_WIRED;
 	g_array_append_val (array, data);
 
diff --git a/src/connection-editor/nm-connection-editor.c b/src/connection-editor/nm-connection-editor.c
index fb321c8..84dda1c 100644
--- a/src/connection-editor/nm-connection-editor.c
+++ b/src/connection-editor/nm-connection-editor.c
@@ -55,10 +55,10 @@
 #include "nma-marshal.h"
 
 #include "ce-page.h"
-#include "page-wired.h"
-#include "page-wired-security.h"
-#include "page-wireless.h"
-#include "page-wireless-security.h"
+#include "page-ethernet.h"
+#include "page-8021x-security.h"
+#include "page-wifi.h"
+#include "page-wifi-security.h"
 #include "page-ip4.h"
 #include "page-ip6.h"
 #include "page-dsl.h"
@@ -742,18 +742,18 @@ nm_connection_editor_set_connection (NMConnectionEditor *editor,
 
 	connection_type = nm_setting_connection_get_connection_type (s_con);
 	if (!strcmp (connection_type, NM_SETTING_WIRED_SETTING_NAME)) {
-		if (!add_page (editor, ce_page_wired_new, editor->connection, error))
+		if (!add_page (editor, ce_page_ethernet_new, editor->connection, error))
 			goto out;
-		if (!add_page (editor, ce_page_wired_security_new, editor->connection, error))
+		if (!add_page (editor, ce_page_8021x_security_new, editor->connection, error))
 			goto out;
 		if (!add_page (editor, ce_page_ip4_new, editor->connection, error))
 			goto out;
 		if (!add_page (editor, ce_page_ip6_new, editor->connection, error))
 			goto out;
 	} else if (!strcmp (connection_type, NM_SETTING_WIRELESS_SETTING_NAME)) {
-		if (!add_page (editor, ce_page_wireless_new, editor->connection, error))
+		if (!add_page (editor, ce_page_wifi_new, editor->connection, error))
 			goto out;
-		if (!add_page (editor, ce_page_wireless_security_new, editor->connection, error))
+		if (!add_page (editor, ce_page_wifi_security_new, editor->connection, error))
 			goto out;
 		if (!add_page (editor, ce_page_ip4_new, editor->connection, error))
 			goto out;
@@ -770,7 +770,7 @@ nm_connection_editor_set_connection (NMConnectionEditor *editor,
 	} else if (!strcmp (connection_type, NM_SETTING_PPPOE_SETTING_NAME)) {
 		if (!add_page (editor, ce_page_dsl_new, editor->connection, error))
 			goto out;
-		if (!add_page (editor, ce_page_wired_new, editor->connection, error))
+		if (!add_page (editor, ce_page_ethernet_new, editor->connection, error))
 			goto out;
 		if (!add_page (editor, ce_page_ppp_new, editor->connection, error))
 			goto out;
diff --git a/src/connection-editor/nm-connection-list.c b/src/connection-editor/nm-connection-list.c
index 0972985..b2f25c1 100644
--- a/src/connection-editor/nm-connection-list.c
+++ b/src/connection-editor/nm-connection-list.c
@@ -48,13 +48,6 @@
 #include <nm-remote-settings.h>
 
 #include "ce-page.h"
-#include "page-wired.h"
-#include "page-wireless.h"
-#include "page-mobile.h"
-#include "page-dsl.h"
-#include "page-vpn.h"
-#include "page-wimax.h"
-#include "page-infiniband.h"
 #include "nm-connection-editor.h"
 #include "nm-connection-list.h"
 #include "vpn-helpers.h"
diff --git a/src/connection-editor/page-wired-security.c b/src/connection-editor/page-8021x-security.c
similarity index 82%
rename from src/connection-editor/page-wired-security.c
rename to src/connection-editor/page-8021x-security.c
index 21dc78c..3bd0980 100644
--- a/src/connection-editor/page-wired-security.c
+++ b/src/connection-editor/page-8021x-security.c
@@ -35,13 +35,13 @@
 #include <nm-utils.h>
 
 #include "wireless-security.h"
-#include "page-wired.h"
-#include "page-wired-security.h"
+#include "page-ethernet.h"
+#include "page-8021x-security.h"
 #include "nm-connection-editor.h"
 
-G_DEFINE_TYPE (CEPageWiredSecurity, ce_page_wired_security, CE_TYPE_PAGE)
+G_DEFINE_TYPE (CEPage8021xSecurity, ce_page_8021x_security, CE_TYPE_PAGE)
 
-#define CE_PAGE_WIRED_SECURITY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CE_TYPE_PAGE_WIRED_SECURITY, CEPageWiredSecurityPrivate))
+#define CE_PAGE_8021X_SECURITY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CE_TYPE_PAGE_8021X_SECURITY, CEPage8021xSecurityPrivate))
 
 typedef struct {
 	GtkToggleButton *enabled;
@@ -51,7 +51,7 @@ typedef struct {
 	gboolean initial_have_8021x;
 
 	gboolean disposed;
-} CEPageWiredSecurityPrivate;
+} CEPage8021xSecurityPrivate;
 
 static void
 stuff_changed (WirelessSecurity *sec, gpointer user_data)
@@ -62,17 +62,17 @@ stuff_changed (WirelessSecurity *sec, gpointer user_data)
 static void
 enable_toggled (GtkToggleButton *button, gpointer user_data)
 {
-	CEPageWiredSecurityPrivate *priv = CE_PAGE_WIRED_SECURITY_GET_PRIVATE (user_data);
+	CEPage8021xSecurityPrivate *priv = CE_PAGE_8021X_SECURITY_GET_PRIVATE (user_data);
 
 	gtk_widget_set_sensitive (priv->security_widget, gtk_toggle_button_get_active (priv->enabled));
 	ce_page_changed (CE_PAGE (user_data));
 }
 
 static void
-finish_setup (CEPageWiredSecurity *self, gpointer unused, GError *error, gpointer user_data)
+finish_setup (CEPage8021xSecurity *self, gpointer unused, GError *error, gpointer user_data)
 {
 	CEPage *parent = CE_PAGE (self);
-	CEPageWiredSecurityPrivate *priv = CE_PAGE_WIRED_SECURITY_GET_PRIVATE (self);
+	CEPage8021xSecurityPrivate *priv = CE_PAGE_8021X_SECURITY_GET_PRIVATE (self);
 	GtkWidget *parent_container;
 
 	if (error)
@@ -100,17 +100,17 @@ finish_setup (CEPageWiredSecurity *self, gpointer unused, GError *error, gpointe
 }
 
 CEPage *
-ce_page_wired_security_new (NMConnection *connection,
+ce_page_8021x_security_new (NMConnection *connection,
                             GtkWindow *parent_window,
                             NMClient *client,
                             const char **out_secrets_setting_name,
                             GError **error)
 {
-	CEPageWiredSecurity *self;
-	CEPageWiredSecurityPrivate *priv;
+	CEPage8021xSecurity *self;
+	CEPage8021xSecurityPrivate *priv;
 	CEPage *parent;
 
-	self = CE_PAGE_WIRED_SECURITY (ce_page_new (CE_TYPE_PAGE_WIRED_SECURITY,
+	self = CE_PAGE_8021X_SECURITY (ce_page_new (CE_TYPE_PAGE_8021X_SECURITY,
 	                                            connection,
 	                                            parent_window,
 	                                            client,
@@ -123,7 +123,7 @@ ce_page_wired_security_new (NMConnection *connection,
 	}
 
 	parent = CE_PAGE (self);
-	priv = CE_PAGE_WIRED_SECURITY_GET_PRIVATE (self);
+	priv = CE_PAGE_8021X_SECURITY_GET_PRIVATE (self);
 
 #if GTK_CHECK_VERSION (3,1,6)
 	parent->page = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
@@ -149,7 +149,7 @@ ce_page_wired_security_new (NMConnection *connection,
 static gboolean
 validate (CEPage *page, NMConnection *connection, GError **error)
 {
-	CEPageWiredSecurityPrivate *priv = CE_PAGE_WIRED_SECURITY_GET_PRIVATE (page);
+	CEPage8021xSecurityPrivate *priv = CE_PAGE_8021X_SECURITY_GET_PRIVATE (page);
 	gboolean valid = TRUE;
 
 	if (gtk_toggle_button_get_active (priv->enabled)) {
@@ -190,20 +190,20 @@ validate (CEPage *page, NMConnection *connection, GError **error)
 static GtkWidget *
 nag_user (CEPage *page)
 {
-	CEPageWiredSecurityPrivate *priv = CE_PAGE_WIRED_SECURITY_GET_PRIVATE (page);
+	CEPage8021xSecurityPrivate *priv = CE_PAGE_8021X_SECURITY_GET_PRIVATE (page);
 
 	return priv->security ? wireless_security_nag_user (priv->security) : NULL;
 }
 
 static void
-ce_page_wired_security_init (CEPageWiredSecurity *self)
+ce_page_8021x_security_init (CEPage8021xSecurity *self)
 {
 }
 
 static void
 dispose (GObject *object)
 {
-	CEPageWiredSecurityPrivate *priv = CE_PAGE_WIRED_SECURITY_GET_PRIVATE (object);
+	CEPage8021xSecurityPrivate *priv = CE_PAGE_8021X_SECURITY_GET_PRIVATE (object);
 
 	if (priv->disposed)
 		return;
@@ -213,16 +213,16 @@ dispose (GObject *object)
 	if (priv->security)
 		wireless_security_unref (priv->security);
 
-	G_OBJECT_CLASS (ce_page_wired_security_parent_class)->dispose (object);
+	G_OBJECT_CLASS (ce_page_8021x_security_parent_class)->dispose (object);
 }
 
 static void
-ce_page_wired_security_class_init (CEPageWiredSecurityClass *wired_security_class)
+ce_page_8021x_security_class_init (CEPage8021xSecurityClass *security_class)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (wired_security_class);
-	CEPageClass *parent_class = CE_PAGE_CLASS (wired_security_class);
+	GObjectClass *object_class = G_OBJECT_CLASS (security_class);
+	CEPageClass *parent_class = CE_PAGE_CLASS (security_class);
 
-	g_type_class_add_private (object_class, sizeof (CEPageWiredSecurityPrivate));
+	g_type_class_add_private (object_class, sizeof (CEPage8021xSecurityPrivate));
 
 	/* virtual methods */
 	object_class->dispose = dispose;
diff --git a/src/connection-editor/page-wired-security.h b/src/connection-editor/page-8021x-security.h
similarity index 60%
rename from src/connection-editor/page-wired-security.h
rename to src/connection-editor/page-8021x-security.h
index 38638c8..02e59de 100644
--- a/src/connection-editor/page-wired-security.h
+++ b/src/connection-editor/page-8021x-security.h
@@ -20,8 +20,8 @@
  * (C) Copyright 2008 - 2011 Red Hat, Inc.
  */
 
-#ifndef __PAGE_WIRED_SECURITY_H__
-#define __PAGE_WIRED_SECURITY_H__
+#ifndef __PAGE_8021X_SECURITY_H__
+#define __PAGE_8021X_SECURITY_H__
 
 #include "nm-connection-editor.h"
 
@@ -32,27 +32,27 @@
 
 #include "ce-page.h"
 
-#define CE_TYPE_PAGE_WIRED_SECURITY            (ce_page_wired_security_get_type ())
-#define CE_PAGE_WIRED_SECURITY(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), CE_TYPE_PAGE_WIRED_SECURITY, CEPageWiredSecurity))
-#define CE_PAGE_WIRED_SECURITY_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), CE_TYPE_PAGE_WIRED_SECURITY, CEPageWiredSecurityClass))
-#define CE_IS_PAGE_WIRED_SECURITY(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CE_TYPE_PAGE_WIRED_SECURITY))
-#define CE_IS_PAGE_WIRED_SECURITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), CE_TYPE_PAGE_WIRED_SECURITY))
-#define CE_PAGE_WIRED_SECURITY_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), CE_TYPE_PAGE_WIRED_SECURITY, CEPageWiredSecurityClass))
+#define CE_TYPE_PAGE_8021X_SECURITY            (ce_page_8021x_security_get_type ())
+#define CE_PAGE_8021X_SECURITY(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), CE_TYPE_PAGE_8021X_SECURITY, CEPage8021xSecurity))
+#define CE_PAGE_8021X_SECURITY_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), CE_TYPE_PAGE_8021X_SECURITY, CEPage8021xSecurityClass))
+#define CE_IS_PAGE_8021X_SECURITY(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CE_TYPE_PAGE_8021X_SECURITY))
+#define CE_IS_PAGE_8021X_SECURITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), CE_TYPE_PAGE_8021X_SECURITY))
+#define CE_PAGE_8021X_SECURITY_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), CE_TYPE_PAGE_8021X_SECURITY, CEPage8021xSecurityClass))
 
 typedef struct {
 	CEPage parent;
-} CEPageWiredSecurity;
+} CEPage8021xSecurity;
 
 typedef struct {
 	CEPageClass parent;
-} CEPageWiredSecurityClass;
+} CEPage8021xSecurityClass;
 
-GType ce_page_wired_security_get_type (void);
+GType ce_page_8021x_security_get_type (void);
 
-CEPage *ce_page_wired_security_new (NMConnection *connection,
+CEPage *ce_page_8021x_security_new (NMConnection *connection,
                                     GtkWindow *parent,
                                     NMClient *client,
                                     const char **out_secrets_setting_name,
                                     GError **error);
 
-#endif  /* __PAGE_WIRED_SECURITY_H__ */
+#endif  /* __PAGE_8021X_SECURITY_H__ */
diff --git a/src/connection-editor/page-wired.c b/src/connection-editor/page-ethernet.c
similarity index 81%
rename from src/connection-editor/page-wired.c
rename to src/connection-editor/page-ethernet.c
index 8f0b81c..0a2d303 100644
--- a/src/connection-editor/page-wired.c
+++ b/src/connection-editor/page-ethernet.c
@@ -32,11 +32,11 @@
 #include <nm-setting-wired.h>
 #include <nm-device-ethernet.h>
 
-#include "page-wired.h"
+#include "page-ethernet.h"
 
-G_DEFINE_TYPE (CEPageWired, ce_page_wired, CE_TYPE_PAGE)
+G_DEFINE_TYPE (CEPageEthernet, ce_page_ethernet, CE_TYPE_PAGE)
 
-#define CE_PAGE_WIRED_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CE_TYPE_PAGE_WIRED, CEPageWiredPrivate))
+#define CE_PAGE_ETHERNET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CE_TYPE_PAGE_ETHERNET, CEPageEthernetPrivate))
 
 typedef struct {
 	NMSettingWired *setting;
@@ -54,7 +54,7 @@ typedef struct {
 	GtkSpinButton *mtu;
 
 	gboolean disposed;
-} CEPageWiredPrivate;
+} CEPageEthernetPrivate;
 
 #define PORT_DEFAULT  0
 #define PORT_TP       1
@@ -69,9 +69,9 @@ typedef struct {
 #define SPEED_10000   4
 
 static void
-wired_private_init (CEPageWired *self)
+ethernet_private_init (CEPageEthernet *self)
 {
-	CEPageWiredPrivate *priv = CE_PAGE_WIRED_GET_PRIVATE (self);
+	CEPageEthernetPrivate *priv = CE_PAGE_ETHERNET_GET_PRIVATE (self);
 	GtkBuilder *builder;
 	GtkWidget *align;
 	GtkLabel *label;
@@ -88,20 +88,20 @@ wired_private_init (CEPageWired *self)
 	gtk_widget_set_tooltip_text (GTK_WIDGET (priv->device_mac),
 	                             _("This option locks this connection to the network device specified by its permanent MAC address entered here.  Example: 00:11:22:33:44:55"));
 
-	align = GTK_WIDGET (gtk_builder_get_object (builder, "wired_device_mac_alignment"));
+	align = GTK_WIDGET (gtk_builder_get_object (builder, "ethernet_device_mac_alignment"));
 	gtk_container_add (GTK_CONTAINER (align), GTK_WIDGET (priv->device_mac));
 	gtk_widget_show_all (GTK_WIDGET (priv->device_mac));
 
 	/* Set mnemonic widget for device MAC label */
-	label = GTK_LABEL (GTK_WIDGET (gtk_builder_get_object (builder, "wired_device_mac_label")));
+	label = GTK_LABEL (GTK_WIDGET (gtk_builder_get_object (builder, "ethernet_device_mac_label")));
 	gtk_label_set_mnemonic_widget (label, GTK_WIDGET (priv->device_mac));
 
-	priv->cloned_mac = GTK_ENTRY (GTK_WIDGET (gtk_builder_get_object (builder, "wired_cloned_mac")));
-	priv->port = GTK_COMBO_BOX (GTK_WIDGET (gtk_builder_get_object (builder, "wired_port")));
-	priv->speed = GTK_COMBO_BOX (GTK_WIDGET (gtk_builder_get_object (builder, "wired_speed")));
-	priv->duplex = GTK_TOGGLE_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "wired_duplex")));
-	priv->autonegotiate = GTK_TOGGLE_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "wired_autonegotiate")));
-	priv->mtu = GTK_SPIN_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "wired_mtu")));
+	priv->cloned_mac = GTK_ENTRY (GTK_WIDGET (gtk_builder_get_object (builder, "ethernet_cloned_mac")));
+	priv->port = GTK_COMBO_BOX (GTK_WIDGET (gtk_builder_get_object (builder, "ethernet_port")));
+	priv->speed = GTK_COMBO_BOX (GTK_WIDGET (gtk_builder_get_object (builder, "ethernet_speed")));
+	priv->duplex = GTK_TOGGLE_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "ethernet_duplex")));
+	priv->autonegotiate = GTK_TOGGLE_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "ethernet_autonegotiate")));
+	priv->mtu = GTK_SPIN_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "ethernet_mtu")));
 }
 
 static void
@@ -111,9 +111,9 @@ stuff_changed (GtkWidget *w, gpointer user_data)
 }
 
 static void
-populate_ui (CEPageWired *self)
+populate_ui (CEPageEthernet *self)
 {
-	CEPageWiredPrivate *priv = CE_PAGE_WIRED_GET_PRIVATE (self);
+	CEPageEthernetPrivate *priv = CE_PAGE_ETHERNET_GET_PRIVATE (self);
 	NMSettingWired *setting = priv->setting;
 	const char *port;
 	const char *duplex;
@@ -220,10 +220,10 @@ populate_ui (CEPageWired *self)
 }
 
 static void
-finish_setup (CEPageWired *self, gpointer unused, GError *error, gpointer user_data)
+finish_setup (CEPageEthernet *self, gpointer unused, GError *error, gpointer user_data)
 {
 	CEPage *parent = CE_PAGE (self);
-	CEPageWiredPrivate *priv = CE_PAGE_WIRED_GET_PRIVATE (self);
+	CEPageEthernetPrivate *priv = CE_PAGE_ETHERNET_GET_PRIVATE (self);
 	GtkWidget *widget;
 
 	if (error)
@@ -238,46 +238,46 @@ finish_setup (CEPageWired *self, gpointer unused, GError *error, gpointer user_d
 	g_signal_connect (priv->mtu, "value-changed", G_CALLBACK (stuff_changed), self);
 
 	/* Hide widgets we don't yet support */
-	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wired_port_label"));
+	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "ethernet_port_label"));
 	gtk_widget_hide (widget);
-	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wired_port"));
+	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "ethernet_port"));
 	gtk_widget_hide (widget);
 
-	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wired_speed_label"));
+	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "ethernet_speed_label"));
 	gtk_widget_hide (widget);
-	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wired_speed"));
+	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "ethernet_speed"));
 	gtk_widget_hide (widget);
 
-	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wired_duplex"));
+	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "ethernet_duplex"));
 	gtk_widget_hide (widget);
-	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wired_autonegotiate"));
+	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "ethernet_autonegotiate"));
 	gtk_widget_hide (widget);
 }
 
 CEPage *
-ce_page_wired_new (NMConnection *connection,
-                   GtkWindow *parent_window,
-                   NMClient *client,
-                   const char **out_secrets_setting_name,
-                   GError **error)
+ce_page_ethernet_new (NMConnection *connection,
+                      GtkWindow *parent_window,
+                      NMClient *client,
+                      const char **out_secrets_setting_name,
+                      GError **error)
 {
-	CEPageWired *self;
-	CEPageWiredPrivate *priv;
-
-	self = CE_PAGE_WIRED (ce_page_new (CE_TYPE_PAGE_WIRED,
-	                                   connection,
-	                                   parent_window,
-	                                   client,
-	                                   UIDIR "/ce-page-wired.ui",
-	                                   "WiredPage",
-	                                   _("Ethernet")));
+	CEPageEthernet *self;
+	CEPageEthernetPrivate *priv;
+
+	self = CE_PAGE_ETHERNET (ce_page_new (CE_TYPE_PAGE_ETHERNET,
+	                                      connection,
+	                                      parent_window,
+	                                      client,
+	                                      UIDIR "/ce-page-ethernet.ui",
+	                                      "EthernetPage",
+	                                      _("Ethernet")));
 	if (!self) {
 		g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("Could not load ethernet user interface."));
 		return NULL;
 	}
 
-	wired_private_init (self);
-	priv = CE_PAGE_WIRED_GET_PRIVATE (self);
+	ethernet_private_init (self);
+	priv = CE_PAGE_ETHERNET_GET_PRIVATE (self);
 
 	priv->setting = nm_connection_get_setting_wired (connection);
 	if (!priv->setting) {
@@ -291,9 +291,9 @@ ce_page_wired_new (NMConnection *connection,
 }
 
 static void
-ui_to_setting (CEPageWired *self)
+ui_to_setting (CEPageEthernet *self)
 {
-	CEPageWiredPrivate *priv = CE_PAGE_WIRED_GET_PRIVATE (self);
+	CEPageEthernetPrivate *priv = CE_PAGE_ETHERNET_GET_PRIVATE (self);
 	const char *port;
 	guint32 speed;
 	GByteArray *device_mac = NULL;
@@ -363,8 +363,8 @@ ui_to_setting (CEPageWired *self)
 static gboolean
 validate (CEPage *page, NMConnection *connection, GError **error)
 {
-	CEPageWired *self = CE_PAGE_WIRED (page);
-	CEPageWiredPrivate *priv = CE_PAGE_WIRED_GET_PRIVATE (self);
+	CEPageEthernet *self = CE_PAGE_ETHERNET (page);
+	CEPageEthernetPrivate *priv = CE_PAGE_ETHERNET_GET_PRIVATE (self);
 	gboolean invalid = FALSE;
 	GByteArray *ignore;
 	GtkWidget *entry;
@@ -421,17 +421,17 @@ get_mac_list (CEPage *page)
 }
 
 static void
-ce_page_wired_init (CEPageWired *self)
+ce_page_ethernet_init (CEPageEthernet *self)
 {
 }
 
 static void
-ce_page_wired_class_init (CEPageWiredClass *wired_class)
+ce_page_ethernet_class_init (CEPageEthernetClass *ethernet_class)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (wired_class);
-	CEPageClass *parent_class = CE_PAGE_CLASS (wired_class);
+	GObjectClass *object_class = G_OBJECT_CLASS (ethernet_class);
+	CEPageClass *parent_class = CE_PAGE_CLASS (ethernet_class);
 
-	g_type_class_add_private (object_class, sizeof (CEPageWiredPrivate));
+	g_type_class_add_private (object_class, sizeof (CEPageEthernetPrivate));
 
 	/* virtual methods */
 	parent_class->validate = validate;
@@ -440,11 +440,11 @@ ce_page_wired_class_init (CEPageWiredClass *wired_class)
 
 
 void
-wired_connection_new (GtkWindow *parent,
-                      const char *detail,
-                      NMRemoteSettings *settings,
-                      PageNewConnectionResultFunc result_func,
-                      gpointer user_data)
+ethernet_connection_new (GtkWindow *parent,
+                         const char *detail,
+                         NMRemoteSettings *settings,
+                         PageNewConnectionResultFunc result_func,
+                         gpointer user_data)
 {
 	NMConnection *connection;
 
diff --git a/src/connection-editor/page-wireless.h b/src/connection-editor/page-ethernet.h
similarity index 52%
copy from src/connection-editor/page-wireless.h
copy to src/connection-editor/page-ethernet.h
index 3d9048e..2ba14be 100644
--- a/src/connection-editor/page-wireless.h
+++ b/src/connection-editor/page-ethernet.h
@@ -20,8 +20,8 @@
  * (C) Copyright 2008 - 2011 Red Hat, Inc.
  */
 
-#ifndef __PAGE_WIRELESS_H__
-#define __PAGE_WIRELESS_H__
+#ifndef __PAGE_ETHERNET_H__
+#define __PAGE_ETHERNET_H__
 
 #include <nm-connection.h>
 
@@ -30,38 +30,34 @@
 
 #include "ce-page.h"
 
-#define CE_TYPE_PAGE_WIRELESS            (ce_page_wireless_get_type ())
-#define CE_PAGE_WIRELESS(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), CE_TYPE_PAGE_WIRELESS, CEPageWireless))
-#define CE_PAGE_WIRELESS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), CE_TYPE_PAGE_WIRELESS, CEPageWirelessClass))
-#define CE_IS_PAGE_WIRELESS(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CE_TYPE_PAGE_WIRELESS))
-#define CE_IS_PAGE_WIRELESS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), CE_TYPE_PAGE_WIRELESS))
-#define CE_PAGE_WIRELESS_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), CE_TYPE_PAGE_WIRELESS, CEPageWirelessClass))
+#define CE_TYPE_PAGE_ETHERNET            (ce_page_ethernet_get_type ())
+#define CE_PAGE_ETHERNET(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), CE_TYPE_PAGE_ETHERNET, CEPageEthernet))
+#define CE_PAGE_ETHERNET_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), CE_TYPE_PAGE_ETHERNET, CEPageEthernetClass))
+#define CE_IS_PAGE_ETHERNET(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CE_TYPE_PAGE_ETHERNET))
+#define CE_IS_PAGE_ETHERNET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), CE_TYPE_PAGE_ETHERNET))
+#define CE_PAGE_ETHERNET_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), CE_TYPE_PAGE_ETHERNET, CEPageEthernetClass))
 
 typedef struct {
 	CEPage parent;
-} CEPageWireless;
+} CEPageEthernet;
 
 typedef struct {
 	CEPageClass parent;
-} CEPageWirelessClass;
+} CEPageEthernetClass;
 
-GType ce_page_wireless_get_type (void);
+GType ce_page_ethernet_get_type (void);
 
-CEPage *ce_page_wireless_new (NMConnection *connection,
+CEPage *ce_page_ethernet_new (NMConnection *connection,
                               GtkWindow *parent,
                               NMClient *client,
                               const char **out_secrets_setting_name,
                               GError **error);
 
-/* Caller must free returned array */
-GByteArray *ce_page_wireless_get_ssid (CEPageWireless *self);
+void ethernet_connection_new (GtkWindow *parent,
+                              const char *detail,
+                              NMRemoteSettings *settings,
+                              PageNewConnectionResultFunc result_func,
+                              gpointer user_data);
 
-
-void wifi_connection_new (GtkWindow *parent,
-                          const char *detail,
-                          NMRemoteSettings *settings,
-                          PageNewConnectionResultFunc result_func,
-                          gpointer user_data);
-
-#endif  /* __PAGE_WIRELESS_H__ */
+#endif  /* __PAGE_ETHERNET_H__ */
 
diff --git a/src/connection-editor/page-ip4.c b/src/connection-editor/page-ip4.c
index 41c9965..7d84de6 100644
--- a/src/connection-editor/page-ip4.c
+++ b/src/connection-editor/page-ip4.c
@@ -189,7 +189,7 @@ ip4_private_init (CEPageIP4 *self, NMConnection *connection)
 		                    -1);
 	}
 
-	/* At the moment, Disabled is only supported for Wired & WiFi */
+	/* At the moment, Disabled is only supported for Ethernet & Wi-Fi */
 	if (   priv->connection_type == NM_TYPE_SETTING_WIRED
 	    || priv->connection_type == NM_TYPE_SETTING_WIRELESS) {
 		gtk_list_store_append (priv->method_store, &iter);
diff --git a/src/connection-editor/page-ip6.c b/src/connection-editor/page-ip6.c
index 353d5ea..7eda2dd 100644
--- a/src/connection-editor/page-ip6.c
+++ b/src/connection-editor/page-ip6.c
@@ -171,7 +171,7 @@ ip6_private_init (CEPageIP6 *self, NMConnection *connection)
 						METHOD_COL_ENABLED, TRUE,
 	                    -1);
 
-	/* DHCP only used on wifi and wired for now */
+	/* DHCP only used on Wi-Fi and ethernet for now */
 	if (   priv->connection_type == NM_TYPE_SETTING_WIRED
 	    || priv->connection_type == NM_TYPE_SETTING_WIRELESS) {
 		gtk_list_store_append (priv->method_store, &iter);
diff --git a/src/connection-editor/page-wireless-security.c b/src/connection-editor/page-wifi-security.c
similarity index 88%
rename from src/connection-editor/page-wireless-security.c
rename to src/connection-editor/page-wifi-security.c
index 4052c70..ad6953b 100644
--- a/src/connection-editor/page-wireless-security.c
+++ b/src/connection-editor/page-wifi-security.c
@@ -35,12 +35,12 @@
 #include <nm-utils.h>
 
 #include "wireless-security.h"
-#include "page-wireless.h"
-#include "page-wireless-security.h"
+#include "page-wifi.h"
+#include "page-wifi-security.h"
 #include "nm-connection-editor.h"
 
 
-G_DEFINE_TYPE (CEPageWirelessSecurity, ce_page_wireless_security, CE_TYPE_PAGE)
+G_DEFINE_TYPE (CEPageWifiSecurity, ce_page_wifi_security, CE_TYPE_PAGE)
 
 
 #define S_NAME_COLUMN   0
@@ -121,7 +121,7 @@ wsec_size_group_clear (GtkSizeGroup *group)
 }
 
 static WirelessSecurity *
-wireless_security_combo_get_active (CEPageWirelessSecurity *self)
+wireless_security_combo_get_active (CEPageWifiSecurity *self)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model;
@@ -138,17 +138,17 @@ static void
 wireless_security_combo_changed (GtkComboBox *combo,
                                  gpointer user_data)
 {
-	CEPageWirelessSecurity *self = CE_PAGE_WIRELESS_SECURITY (user_data);
+	CEPageWifiSecurity *self = CE_PAGE_WIFI_SECURITY (user_data);
 	GtkWidget *vbox;
 	GList *elt, *children;
 	WirelessSecurity *sec;
 
-	vbox = GTK_WIDGET (gtk_builder_get_object (CE_PAGE (self)->builder, "wireless_security_vbox"));
+	vbox = GTK_WIDGET (gtk_builder_get_object (CE_PAGE (self)->builder, "wifi_security_vbox"));
 	g_assert (vbox);
 
 	wsec_size_group_clear (self->group);
 
-	/* Remove any previous wireless security widgets */
+	/* Remove any previous wifi security widgets */
 	children = gtk_container_get_children (GTK_CONTAINER (vbox));
 	for (elt = children; elt; elt = g_list_next (elt))
 		gtk_container_remove (GTK_CONTAINER (vbox), GTK_WIDGET (elt->data));
@@ -164,7 +164,7 @@ wireless_security_combo_changed (GtkComboBox *combo,
 		if (parent)
 			gtk_container_remove (GTK_CONTAINER (parent), sec_widget);
 
-		widget = GTK_WIDGET (gtk_builder_get_object (CE_PAGE (self)->builder, "wireless_security_combo_label"));
+		widget = GTK_WIDGET (gtk_builder_get_object (CE_PAGE (self)->builder, "wifi_security_combo_label"));
 		gtk_size_group_add_widget (self->group, widget);
 		wireless_security_add_to_size_group (sec, self->group);
 
@@ -176,7 +176,7 @@ wireless_security_combo_changed (GtkComboBox *combo,
 }
 
 static void
-add_security_item (CEPageWirelessSecurity *self,
+add_security_item (CEPageWifiSecurity *self,
                    WirelessSecurity *sec,
                    GtkListStore *model,
                    GtkTreeIter *iter,
@@ -211,7 +211,7 @@ set_sensitive (GtkCellLayout *cell_layout,
 }
 
 static void
-finish_setup (CEPageWirelessSecurity *self, gpointer unused, GError *error, gpointer user_data)
+finish_setup (CEPageWifiSecurity *self, gpointer unused, GError *error, gpointer user_data)
 {
 	CEPage *parent = CE_PAGE (self);
 	NMSettingWireless *s_wireless;
@@ -235,7 +235,7 @@ finish_setup (CEPageWirelessSecurity *self, gpointer unused, GError *error, gpoi
 	s_wireless = nm_connection_get_setting_wireless (connection);
 	g_assert (s_wireless);
 
-	combo = GTK_COMBO_BOX (GTK_WIDGET (gtk_builder_get_object (parent->builder, "wireless_security_combo")));
+	combo = GTK_COMBO_BOX (GTK_WIDGET (gtk_builder_get_object (parent->builder, "wifi_security_combo")));
 
 	dev_caps =   NM_WIFI_DEVICE_CAP_CIPHER_WEP40
 	           | NM_WIFI_DEVICE_CAP_CIPHER_WEP104
@@ -262,7 +262,7 @@ finish_setup (CEPageWirelessSecurity *self, gpointer unused, GError *error, gpoi
 	if (nm_utils_security_valid (NMU_SEC_NONE, dev_caps, FALSE, is_adhoc, 0, 0, 0)) {
 		gtk_list_store_append (sec_model, &iter);
 		gtk_list_store_set (sec_model, &iter,
-		                    S_NAME_COLUMN, C_("Wifi/wired security", "None"),
+		                    S_NAME_COLUMN, C_("Wi-Fi/Ethernet security", "None"),
 		                    S_ADHOC_VALID_COLUMN, TRUE,
 		                    -1);
 		if (default_type == NMU_SEC_NONE)
@@ -378,13 +378,13 @@ finish_setup (CEPageWirelessSecurity *self, gpointer unused, GError *error, gpoi
 }
 
 CEPage *
-ce_page_wireless_security_new (NMConnection *connection,
-                               GtkWindow *parent_window,
-                               NMClient *client,
-                               const char **out_secrets_setting_name,
-                               GError **error)
+ce_page_wifi_security_new (NMConnection *connection,
+                           GtkWindow *parent_window,
+                           NMClient *client,
+                           const char **out_secrets_setting_name,
+                           GError **error)
 {
-	CEPageWirelessSecurity *self;
+	CEPageWifiSecurity *self;
 	NMSettingWireless *s_wireless;
 	NMSettingWirelessSecurity *s_wsec = NULL;
 	NMUtilsSecurityType default_type = NMU_SEC_NONE;
@@ -396,13 +396,13 @@ ce_page_wireless_security_new (NMConnection *connection,
 		return NULL;
 	}
 
-	self = CE_PAGE_WIRELESS_SECURITY (ce_page_new (CE_TYPE_PAGE_WIRELESS_SECURITY,
-	                                               connection,
-	                                               parent_window,
-	                                               client,
-	                                               UIDIR "/ce-page-wireless-security.ui",
-	                                               "WirelessSecurityPage",
-	                                               _("Wi-Fi Security")));
+	self = CE_PAGE_WIFI_SECURITY (ce_page_new (CE_TYPE_PAGE_WIFI_SECURITY,
+	                                           connection,
+	                                           parent_window,
+	                                           client,
+	                                           UIDIR "/ce-page-wifi-security.ui",
+	                                           "WifiSecurityPage",
+	                                           _("Wi-Fi Security")));
 	if (!self) {
 		g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("Could not load Wi-Fi security user interface."));
 		return NULL;
@@ -439,7 +439,7 @@ ce_page_wireless_security_new (NMConnection *connection,
 }
 
 static void
-ce_page_wireless_security_init (CEPageWirelessSecurity *self)
+ce_page_wifi_security_init (CEPageWifiSecurity *self)
 {
 	self->disposed = FALSE;
 }
@@ -447,7 +447,7 @@ ce_page_wireless_security_init (CEPageWirelessSecurity *self)
 static void
 dispose (GObject *object)
 {
-	CEPageWirelessSecurity *self = CE_PAGE_WIRELESS_SECURITY (object);
+	CEPageWifiSecurity *self = CE_PAGE_WIFI_SECURITY (object);
 
 	if (self->disposed)
 		return;
@@ -457,13 +457,13 @@ dispose (GObject *object)
 	if (self->group)
 		g_object_unref (self->group);
 
-	G_OBJECT_CLASS (ce_page_wireless_security_parent_class)->dispose (object);
+	G_OBJECT_CLASS (ce_page_wifi_security_parent_class)->dispose (object);
 }
 
 static gboolean
 validate (CEPage *page, NMConnection *connection, GError **error)
 {
-	CEPageWirelessSecurity *self = CE_PAGE_WIRELESS_SECURITY (page);
+	CEPageWifiSecurity *self = CE_PAGE_WIFI_SECURITY (page);
 	NMSettingWireless *s_wireless;
 	WirelessSecurity *sec;
 	gboolean valid = FALSE;
@@ -487,7 +487,7 @@ validate (CEPage *page, NMConnection *connection, GError **error)
 		const GByteArray *ssid = nm_setting_wireless_get_ssid (s_wireless);
 
 		if (ssid) {
-			/* FIXME: get failed property and error out of wireless security objects */
+			/* FIXME: get failed property and error out of wifi security objects */
 			valid = wireless_security_validate (sec, ssid);
 			if (valid)
 				wireless_security_fill_connection (sec, connection);
@@ -523,7 +523,7 @@ nag_user (CEPage *page)
 	WirelessSecurity *sec;
 	GtkWidget *nag = NULL;
 
-	sec = wireless_security_combo_get_active (CE_PAGE_WIRELESS_SECURITY (page));
+	sec = wireless_security_combo_get_active (CE_PAGE_WIFI_SECURITY (page));
 	if (sec) {
 		nag = wireless_security_nag_user (sec);
 		wireless_security_unref (sec);
@@ -532,7 +532,7 @@ nag_user (CEPage *page)
 }
 
 static void
-ce_page_wireless_security_class_init (CEPageWirelessSecurityClass *wireless_security_class)
+ce_page_wifi_security_class_init (CEPageWifiSecurityClass *wireless_security_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (wireless_security_class);
 	CEPageClass *parent_class = CE_PAGE_CLASS (wireless_security_class);
diff --git a/src/connection-editor/page-wifi-security.h b/src/connection-editor/page-wifi-security.h
new file mode 100644
index 0000000..516fb88
--- /dev/null
+++ b/src/connection-editor/page-wifi-security.h
@@ -0,0 +1,65 @@
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* NetworkManager Connection editor -- Connection editor for NetworkManager
+ *
+ * Dan Williams <dcbw redhat com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * (C) Copyright 2008 - 2011 Red Hat, Inc.
+ */
+
+#ifndef __PAGE_WIFI_SECURITY_H__
+#define __PAGE_WIFI_SECURITY_H__
+
+#include "nm-connection-editor.h"
+
+#include <nm-connection.h>
+
+#include <glib.h>
+#include <glib-object.h>
+#include <gtk/gtk.h>
+
+#include "ce-page.h"
+
+#define CE_TYPE_PAGE_WIFI_SECURITY            (ce_page_wifi_security_get_type ())
+#define CE_PAGE_WIFI_SECURITY(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), CE_TYPE_PAGE_WIFI_SECURITY, CEPageWifiSecurity))
+#define CE_PAGE_WIFI_SECURITY_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), CE_TYPE_PAGE_WIFI_SECURITY, CEPageWifiSecurityClass))
+#define CE_IS_PAGE_WIFI_SECURITY(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CE_TYPE_PAGE_WIFI_SECURITY))
+#define CE_IS_PAGE_WIFI_SECURITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), CE_TYPE_PAGE_WIFI_SECURITY))
+#define CE_PAGE_WIFI_SECURITY_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), CE_TYPE_PAGE_WIFI_SECURITY, CEPageWifiSecurityClass))
+
+typedef struct {
+	CEPage parent;
+
+	gboolean disposed;
+	GtkSizeGroup *group;
+	GtkComboBox *security_combo;
+	gboolean adhoc;
+} CEPageWifiSecurity;
+
+typedef struct {
+	CEPageClass parent;
+} CEPageWifiSecurityClass;
+
+GType ce_page_wifi_security_get_type (void);
+
+CEPage *ce_page_wifi_security_new (NMConnection *connection,
+                                   GtkWindow *parent,
+                                   NMClient *client,
+                                   const char **out_secrets_setting_name,
+                                   GError **error);
+
+#endif  /* __PAGE_WIFI_SECURITY_H__ */
+
diff --git a/src/connection-editor/page-wireless.h b/src/connection-editor/page-wifi.h
similarity index 55%
rename from src/connection-editor/page-wireless.h
rename to src/connection-editor/page-wifi.h
index 3d9048e..95b2f10 100644
--- a/src/connection-editor/page-wireless.h
+++ b/src/connection-editor/page-wifi.h
@@ -20,8 +20,8 @@
  * (C) Copyright 2008 - 2011 Red Hat, Inc.
  */
 
-#ifndef __PAGE_WIRELESS_H__
-#define __PAGE_WIRELESS_H__
+#ifndef __PAGE_WIFI_H__
+#define __PAGE_WIFI_H__
 
 #include <nm-connection.h>
 
@@ -30,31 +30,31 @@
 
 #include "ce-page.h"
 
-#define CE_TYPE_PAGE_WIRELESS            (ce_page_wireless_get_type ())
-#define CE_PAGE_WIRELESS(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), CE_TYPE_PAGE_WIRELESS, CEPageWireless))
-#define CE_PAGE_WIRELESS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), CE_TYPE_PAGE_WIRELESS, CEPageWirelessClass))
-#define CE_IS_PAGE_WIRELESS(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CE_TYPE_PAGE_WIRELESS))
-#define CE_IS_PAGE_WIRELESS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), CE_TYPE_PAGE_WIRELESS))
-#define CE_PAGE_WIRELESS_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), CE_TYPE_PAGE_WIRELESS, CEPageWirelessClass))
+#define CE_TYPE_PAGE_WIFI            (ce_page_wifi_get_type ())
+#define CE_PAGE_WIFI(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), CE_TYPE_PAGE_WIFI, CEPageWifi))
+#define CE_PAGE_WIFI_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), CE_TYPE_PAGE_WIFI, CEPageWifiClass))
+#define CE_IS_PAGE_WIFI(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CE_TYPE_PAGE_WIFI))
+#define CE_IS_PAGE_WIFI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), CE_TYPE_PAGE_WIFI))
+#define CE_PAGE_WIFI_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), CE_TYPE_PAGE_WIFI, CEPageWifiClass))
 
 typedef struct {
 	CEPage parent;
-} CEPageWireless;
+} CEPageWifi;
 
 typedef struct {
 	CEPageClass parent;
-} CEPageWirelessClass;
+} CEPageWifiClass;
 
-GType ce_page_wireless_get_type (void);
+GType ce_page_wifi_get_type (void);
 
-CEPage *ce_page_wireless_new (NMConnection *connection,
-                              GtkWindow *parent,
-                              NMClient *client,
-                              const char **out_secrets_setting_name,
-                              GError **error);
+CEPage *ce_page_wifi_new (NMConnection *connection,
+                          GtkWindow *parent,
+                          NMClient *client,
+                          const char **out_secrets_setting_name,
+                          GError **error);
 
 /* Caller must free returned array */
-GByteArray *ce_page_wireless_get_ssid (CEPageWireless *self);
+GByteArray *ce_page_wifi_get_ssid (CEPageWifi *self);
 
 
 void wifi_connection_new (GtkWindow *parent,
@@ -63,5 +63,5 @@ void wifi_connection_new (GtkWindow *parent,
                           PageNewConnectionResultFunc result_func,
                           gpointer user_data);
 
-#endif  /* __PAGE_WIRELESS_H__ */
+#endif  /* __PAGE_WIFI_H__ */
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/connection-editor/page-wireless.c b/src/connection-editor/page-wifi.c
similarity index 84%
rename from src/connection-editor/page-wireless.c
rename to src/connection-editor/page-wifi.c
index 4a03e1d..d28714e 100644
--- a/src/connection-editor/page-wireless.c
+++ b/src/connection-editor/page-wifi.c
@@ -33,11 +33,11 @@
 #include <nm-device-wifi.h>
 #include <nm-utils.h>
 
-#include "page-wireless.h"
+#include "page-wifi.h"
 
-G_DEFINE_TYPE (CEPageWireless, ce_page_wireless, CE_TYPE_PAGE)
+G_DEFINE_TYPE (CEPageWifi, ce_page_wifi, CE_TYPE_PAGE)
 
-#define CE_PAGE_WIRELESS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CE_TYPE_PAGE_WIRELESS, CEPageWirelessPrivate))
+#define CE_PAGE_WIFI_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CE_TYPE_PAGE_WIFI, CEPageWifiPrivate))
 
 typedef struct {
 	NMSettingWireless *setting;
@@ -61,12 +61,12 @@ typedef struct {
 
 	int last_channel;
 	gboolean disposed;
-} CEPageWirelessPrivate;
+} CEPageWifiPrivate;
 
 static void
-wireless_private_init (CEPageWireless *self)
+wifi_private_init (CEPageWifi *self)
 {
-	CEPageWirelessPrivate *priv = CE_PAGE_WIRELESS_GET_PRIVATE (self);
+	CEPageWifiPrivate *priv = CE_PAGE_WIFI_GET_PRIVATE (self);
 	GtkBuilder *builder;
 	GtkWidget *widget;
 	GtkWidget *align;
@@ -76,12 +76,12 @@ wireless_private_init (CEPageWireless *self)
 
 	priv->group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
-	priv->ssid     = GTK_ENTRY (GTK_WIDGET (gtk_builder_get_object (builder, "wireless_ssid")));
-	priv->bssid    = GTK_ENTRY (GTK_WIDGET (gtk_builder_get_object (builder, "wireless_bssid")));
-	priv->cloned_mac = GTK_ENTRY (GTK_WIDGET (gtk_builder_get_object (builder, "wireless_cloned_mac")));
-	priv->mode     = GTK_COMBO_BOX (GTK_WIDGET (gtk_builder_get_object (builder, "wireless_mode")));
-	priv->band     = GTK_COMBO_BOX (GTK_WIDGET (gtk_builder_get_object (builder, "wireless_band")));
-	priv->channel  = GTK_SPIN_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "wireless_channel")));
+	priv->ssid     = GTK_ENTRY (GTK_WIDGET (gtk_builder_get_object (builder, "wifi_ssid")));
+	priv->bssid    = GTK_ENTRY (GTK_WIDGET (gtk_builder_get_object (builder, "wifi_bssid")));
+	priv->cloned_mac = GTK_ENTRY (GTK_WIDGET (gtk_builder_get_object (builder, "wifi_cloned_mac")));
+	priv->mode     = GTK_COMBO_BOX (GTK_WIDGET (gtk_builder_get_object (builder, "wifi_mode")));
+	priv->band     = GTK_COMBO_BOX (GTK_WIDGET (gtk_builder_get_object (builder, "wifi_band")));
+	priv->channel  = GTK_SPIN_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "wifi_channel")));
 
 #if GTK_CHECK_VERSION(2,24,0)
 	priv->device_mac = GTK_COMBO_BOX_TEXT (gtk_combo_box_text_new_with_entry ());
@@ -93,31 +93,31 @@ wireless_private_init (CEPageWireless *self)
 	gtk_widget_set_tooltip_text (GTK_WIDGET (priv->device_mac),
 	                             _("This option locks this connection to the network device specified by its permanent MAC address entered here.  Example: 00:11:22:33:44:55"));
 
-	align = GTK_WIDGET (gtk_builder_get_object (builder, "wireless_device_mac_alignment"));
+	align = GTK_WIDGET (gtk_builder_get_object (builder, "wifi_device_mac_alignment"));
 	gtk_container_add (GTK_CONTAINER (align), GTK_WIDGET (priv->device_mac));
 	gtk_widget_show_all (GTK_WIDGET (priv->device_mac));
 
 	/* Set mnemonic widget for device MAC label */
-	label = GTK_LABEL (GTK_WIDGET (gtk_builder_get_object (builder, "wireless_device_mac_label")));
+	label = GTK_LABEL (GTK_WIDGET (gtk_builder_get_object (builder, "wifi_device_mac_label")));
 	gtk_label_set_mnemonic_widget (label, GTK_WIDGET (priv->device_mac));
 
-	priv->rate     = GTK_SPIN_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "wireless_rate")));
+	priv->rate     = GTK_SPIN_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "wifi_rate")));
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "rate_units"));
 	gtk_size_group_add_widget (priv->group, widget);
 
-	priv->tx_power = GTK_SPIN_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "wireless_tx_power")));
+	priv->tx_power = GTK_SPIN_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "wifi_tx_power")));
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "tx_power_units"));
 	gtk_size_group_add_widget (priv->group, widget);
 
-	priv->mtu      = GTK_SPIN_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "wireless_mtu")));
+	priv->mtu      = GTK_SPIN_BUTTON (GTK_WIDGET (gtk_builder_get_object (builder, "wifi_mtu")));
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "mtu_units"));
 	gtk_size_group_add_widget (priv->group, widget);
 }
 
 static gboolean
-band_helper (CEPageWireless *self, gboolean *aband, gboolean *gband)
+band_helper (CEPageWifi *self, gboolean *aband, gboolean *gband)
 {
-	CEPageWirelessPrivate *priv = CE_PAGE_WIRELESS_GET_PRIVATE (self);
+	CEPageWifiPrivate *priv = CE_PAGE_WIFI_GET_PRIVATE (self);
 
 	switch (gtk_combo_box_get_active (priv->band)) {
 	case 1: /* A */
@@ -134,7 +134,7 @@ band_helper (CEPageWireless *self, gboolean *aband, gboolean *gband)
 static gint
 channel_spin_input_cb (GtkSpinButton *spin, gdouble *new_val, gpointer user_data)
 {
-	CEPageWireless *self = CE_PAGE_WIRELESS (user_data);
+	CEPageWifi *self = CE_PAGE_WIFI (user_data);
 	gdouble channel;
 	guint32 int_channel = 0;
 	gboolean aband = TRUE;
@@ -159,8 +159,8 @@ channel_spin_input_cb (GtkSpinButton *spin, gdouble *new_val, gpointer user_data
 static gint
 channel_spin_output_cb (GtkSpinButton *spin, gpointer user_data)
 {
-	CEPageWireless *self = CE_PAGE_WIRELESS (user_data);
-	CEPageWirelessPrivate *priv = CE_PAGE_WIRELESS_GET_PRIVATE (self);
+	CEPageWifi *self = CE_PAGE_WIFI (user_data);
+	CEPageWifiPrivate *priv = CE_PAGE_WIFI_GET_PRIVATE (self);
 	int channel;
 	gchar *buf = NULL;
 	guint32 freq;
@@ -213,8 +213,8 @@ out:
 static void
 band_value_changed_cb (GtkComboBox *box, gpointer user_data)
 {
-	CEPageWireless *self = CE_PAGE_WIRELESS (user_data);
-	CEPageWirelessPrivate *priv = CE_PAGE_WIRELESS_GET_PRIVATE (self);
+	CEPageWifi *self = CE_PAGE_WIFI (user_data);
+	CEPageWifiPrivate *priv = CE_PAGE_WIFI_GET_PRIVATE (self);
 	gboolean sensitive;
 
 	priv->last_channel = 0;
@@ -239,8 +239,8 @@ static void
 mode_combo_changed_cb (GtkComboBox *combo,
                        gpointer user_data)
 {
-	CEPageWireless *self = CE_PAGE_WIRELESS (user_data);
-	CEPageWirelessPrivate *priv = CE_PAGE_WIRELESS_GET_PRIVATE (self);
+	CEPageWifi *self = CE_PAGE_WIFI (user_data);
+	CEPageWifiPrivate *priv = CE_PAGE_WIFI_GET_PRIVATE (self);
 	CEPage *parent = CE_PAGE (self);
 	GtkWidget *widget;
 	gboolean show;
@@ -255,25 +255,25 @@ mode_combo_changed_cb (GtkComboBox *combo,
  	}
 
 	if (show) {
-		widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wireless_band_label"));
+		widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wifi_band_label"));
 		gtk_widget_show (widget);
 		gtk_widget_show (GTK_WIDGET (priv->band));
-		widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wireless_channel_label"));
+		widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wifi_channel_label"));
 		gtk_widget_show (widget);
 		gtk_widget_show (GTK_WIDGET (priv->channel));
 	} else {
-		widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wireless_band_label"));
+		widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wifi_band_label"));
 		gtk_widget_hide (widget);
 		gtk_widget_hide (GTK_WIDGET (priv->band));
-		widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wireless_channel_label"));
+		widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wifi_channel_label"));
 		gtk_widget_hide (widget);
 		gtk_widget_hide (GTK_WIDGET (priv->channel));
 	}
 
-	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wireless_band_label"));
+	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wifi_band_label"));
 	gtk_widget_set_sensitive (GTK_WIDGET (widget), show);
 	gtk_widget_set_sensitive (GTK_WIDGET (priv->band), show);
-	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wireless_channel_label"));
+	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wifi_channel_label"));
 	gtk_widget_set_sensitive (GTK_WIDGET (widget), show);
 	gtk_widget_set_sensitive (GTK_WIDGET (priv->channel), show);
 
@@ -281,9 +281,9 @@ mode_combo_changed_cb (GtkComboBox *combo,
 }
 
 static void
-populate_ui (CEPageWireless *self)
+populate_ui (CEPageWifi *self)
 {
-	CEPageWirelessPrivate *priv = CE_PAGE_WIRELESS_GET_PRIVATE (self);
+	CEPageWifiPrivate *priv = CE_PAGE_WIFI_GET_PRIVATE (self);
 	NMSettingWireless *setting = priv->setting;
 	GByteArray *ssid = NULL;
 	char *mode = NULL;
@@ -420,7 +420,7 @@ populate_ui (CEPageWireless *self)
 }
 
 static void
-finish_setup (CEPageWireless *self, gpointer unused, GError *error, gpointer user_data)
+finish_setup (CEPageWifi *self, gpointer unused, GError *error, gpointer user_data)
 {
 	CEPage *parent = CE_PAGE (self);
 	GtkWidget *widget;
@@ -430,43 +430,43 @@ finish_setup (CEPageWireless *self, gpointer unused, GError *error, gpointer use
 
 	populate_ui (self);
 
-	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wireless_tx_power_label"));
+	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wifi_tx_power_label"));
 	gtk_widget_hide (widget);
-	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wireless_tx_power_hbox"));
+	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wifi_tx_power_hbox"));
 	gtk_widget_hide (widget);
 
-	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wireless_rate_label"));
+	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wifi_rate_label"));
 	gtk_widget_hide (widget);
-	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wireless_rate_hbox"));
+	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wifi_rate_hbox"));
 	gtk_widget_hide (widget);
 }
 
 CEPage *
-ce_page_wireless_new (NMConnection *connection,
-                      GtkWindow *parent_window,
-                      NMClient *client,
-                      const char **out_secrets_setting_name,
-                      GError **error)
+ce_page_wifi_new (NMConnection *connection,
+                  GtkWindow *parent_window,
+                  NMClient *client,
+                  const char **out_secrets_setting_name,
+                  GError **error)
 {
-	CEPageWireless *self;
-	CEPageWirelessPrivate *priv;
+	CEPageWifi *self;
+	CEPageWifiPrivate *priv;
 
 	g_return_val_if_fail (NM_IS_CONNECTION (connection), NULL);
 
-	self = CE_PAGE_WIRELESS (ce_page_new (CE_TYPE_PAGE_WIRELESS,
-	                                      connection,
-	                                      parent_window,
-	                                      client,
-	                                      UIDIR "/ce-page-wireless.ui",
-	                                      "WirelessPage",
-	                                      _("Wi-Fi")));
+	self = CE_PAGE_WIFI (ce_page_new (CE_TYPE_PAGE_WIFI,
+	                                  connection,
+	                                  parent_window,
+	                                  client,
+	                                  UIDIR "/ce-page-wifi.ui",
+	                                  "WifiPage",
+	                                  _("Wi-Fi")));
 	if (!self) {
 		g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("Could not load Wi-Fi user interface."));
 		return NULL;
 	}
 
-	wireless_private_init (self);
-	priv = CE_PAGE_WIRELESS_GET_PRIVATE (self);
+	wifi_private_init (self);
+	priv = CE_PAGE_WIFI_GET_PRIVATE (self);
 
 	priv->setting = nm_connection_get_setting_wireless (connection);
 	if (!priv->setting) {
@@ -480,15 +480,15 @@ ce_page_wireless_new (NMConnection *connection,
 }
 
 GByteArray *
-ce_page_wireless_get_ssid (CEPageWireless *self)
+ce_page_wifi_get_ssid (CEPageWifi *self)
 {
-	CEPageWirelessPrivate *priv;
+	CEPageWifiPrivate *priv;
 	const char *txt_ssid;
 	GByteArray *ssid;
 
-	g_return_val_if_fail (CE_IS_PAGE_WIRELESS (self), NULL);
+	g_return_val_if_fail (CE_IS_PAGE_WIFI (self), NULL);
 
-	priv = CE_PAGE_WIRELESS_GET_PRIVATE (self);
+	priv = CE_PAGE_WIFI_GET_PRIVATE (self);
 	txt_ssid = gtk_entry_get_text (priv->ssid);
 	if (!txt_ssid || !strlen (txt_ssid))
 		return NULL;
@@ -500,9 +500,9 @@ ce_page_wireless_get_ssid (CEPageWireless *self)
 }
 
 static void
-ui_to_setting (CEPageWireless *self)
+ui_to_setting (CEPageWifi *self)
 {
-	CEPageWirelessPrivate *priv = CE_PAGE_WIRELESS_GET_PRIVATE (self);
+	CEPageWifiPrivate *priv = CE_PAGE_WIFI_GET_PRIVATE (self);
 	GByteArray *ssid;
 	GByteArray *bssid = NULL;
 	GByteArray *device_mac = NULL;
@@ -511,7 +511,7 @@ ui_to_setting (CEPageWireless *self)
 	const char *band;
 	GtkWidget *entry;
 
-	ssid = ce_page_wireless_get_ssid (self);
+	ssid = ce_page_wifi_get_ssid (self);
 
 	if (gtk_combo_box_get_active (priv->mode) == 1)
 		mode = "adhoc";
@@ -563,8 +563,8 @@ ui_to_setting (CEPageWireless *self)
 static gboolean
 validate (CEPage *page, NMConnection *connection, GError **error)
 {
-	CEPageWireless *self = CE_PAGE_WIRELESS (page);
-	CEPageWirelessPrivate *priv = CE_PAGE_WIRELESS_GET_PRIVATE (self);
+	CEPageWifi *self = CE_PAGE_WIFI (page);
+	CEPageWifiPrivate *priv = CE_PAGE_WIFI_GET_PRIVATE (self);
 	char *security;
 	gboolean success;
 	gboolean invalid = FALSE;
@@ -594,7 +594,7 @@ validate (CEPage *page, NMConnection *connection, GError **error)
 
 	ui_to_setting (self);
 
 	/* A hack to not check the wireless security here */
 	security = g_strdup (nm_setting_wireless_get_security (priv->setting));
 	g_object_set (priv->setting, NM_SETTING_WIRELESS_SEC, NULL, NULL);
 
@@ -638,17 +638,17 @@ get_mac_list (CEPage *page)
 }
 
 static void
-ce_page_wireless_init (CEPageWireless *self)
+ce_page_wifi_init (CEPageWifi *self)
 {
 }
 
 static void
-ce_page_wireless_class_init (CEPageWirelessClass *wireless_class)
+ce_page_wifi_class_init (CEPageWifiClass *wifi_class)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (wireless_class);
-	CEPageClass *parent_class = CE_PAGE_CLASS (wireless_class);
+	GObjectClass *object_class = G_OBJECT_CLASS (wifi_class);
+	CEPageClass *parent_class = CE_PAGE_CLASS (wifi_class);
 
-	g_type_class_add_private (object_class, sizeof (CEPageWirelessPrivate));
+	g_type_class_add_private (object_class, sizeof (CEPageWifiPrivate));
 
 	/* virtual methods */
 	parent_class->validate = validate;
@@ -594,7 +594,7 @@ validate (CEPage *page, NMConnection *connection, GError **error)
 	ui_to_setting (self);
 
-	/* A hack to not check the wireless security here */
+	/* A hack to not check the wifi security here */
 	security = g_strdup (nm_setting_wireless_get_security (priv->setting));
 	g_object_set (priv->setting, NM_SETTING_WIRELESS_SEC, NULL, NULL);